@@ -10,6 +10,7 @@ BF.glm <- function(x,
                    prior.hyp = NULL,
                    complement = TRUE,
                    log = FALSE,
+                   cov.prob = .95,
                    ...){
 
   if(as.character(x$family)[1]=="gaussian"){
@@ -24,6 +25,7 @@ BF.glm <- function(x,
     Args$prior.hyp.explo <- prior.hyp.explo
     Args$complement <- complement
     Args$log <- log
+    Args$cov.prob <- cov.prob
     out <- do.call(BF, Args)
     out$model <- x
     out$call <- match.call()
@@ -41,6 +43,7 @@ BF.glm <- function(x,
     Args$prior.hyp.explo <- prior.hyp.explo
     Args$complement <- complement
     Args$log <- log
+    Args$cov.prob <- cov.prob
     out <- do.call(BF, Args)
     out$model <- x
     out$call <- match.call()
